@@ -54,22 +54,21 @@
 
 
 const struct Cop_T mysqlcops = {
-        "mysql",
-        MysqlConnection_onstop,
-        MysqlConnection_new,
-        MysqlConnection_free,
-        MysqlConnection_setQueryTimeout,
-        MysqlConnection_setMaxRows,
-        MysqlConnection_ping,
-        MysqlConnection_beginTransaction,
-        MysqlConnection_commit,
-        MysqlConnection_rollback,
-        MysqlConnection_lastRowId,
-        MysqlConnection_rowsChanged,
-        MysqlConnection_execute,
-        MysqlConnection_executeQuery,
-        MysqlConnection_prepareStatement,
-        MysqlConnection_getLastError
+        .name 		 	= "mysql",
+        .new 		 	= MysqlConnection_new,
+        .free 		 	= MysqlConnection_free,
+        .setQueryTimeout 	= MysqlConnection_setQueryTimeout,
+        .setMaxRows 	 	= MysqlConnection_setMaxRows,
+        .ping		 	= MysqlConnection_ping,
+        .beginTransaction       = MysqlConnection_beginTransaction,
+        .commit			= MysqlConnection_commit,
+        .rollback		= MysqlConnection_rollback,
+        .lastRowId		= MysqlConnection_lastRowId,
+        .rowsChanged		= MysqlConnection_rowsChanged,
+        .execute		= MysqlConnection_execute,
+        .executeQuery		= MysqlConnection_executeQuery,
+        .prepareStatement	= MysqlConnection_prepareStatement,
+        .getLastError		= MysqlConnection_getLastError
 };
 
 #define T ConnectionDelegate_T
@@ -90,7 +89,7 @@ extern const struct Pop_T mysqlpops;
 /* ------------------------------------------------------- Private methods */
 
 
-static MYSQL *doConnect(URL_T url, char **error) {
+static MYSQL *_doConnect(URL_T url, char **error) {
 #define ERROR(e) do {*error = Str_dup(e); goto error;} while (0)
         int port;
         my_bool yes = 1;
@@ -148,7 +147,7 @@ error:
 }
 
 
-static int prepare(T C, const char *sql, int len, MYSQL_STMT **stmt) {
+static int _prepare(T C, const char *sql, int len, MYSQL_STMT **stmt) {
         if (! (*stmt = mysql_stmt_init(C->db))) {
                 DEBUG("mysql_stmt_init -- Out of memory\n");
                 C->lastError = CR_OUT_OF_MEMORY;
@@ -176,7 +175,7 @@ T MysqlConnection_new(URL_T url, char **error) {
         MYSQL *db;
 	assert(url);
         assert(error);
-        if (! (db = doConnect(url, error)))
+        if (! (db = _doConnect(url, error)))
                 return NULL;
 	NEW(C);
         C->db = db;
@@ -276,7 +275,7 @@ ResultSet_T MysqlConnection_executeQuery(T C, const char *sql, va_list ap) {
         va_copy(ap_copy, ap);
         StringBuffer_vset(C->sb, sql, ap_copy);
         va_end(ap_copy);
-        if (prepare(C, StringBuffer_toString(C->sb), StringBuffer_length(C->sb), &stmt)) {
+        if (_prepare(C, StringBuffer_toString(C->sb), StringBuffer_length(C->sb), &stmt)) {
 #if MYSQL_VERSION_ID >= 50002
                 unsigned long cursor = CURSOR_TYPE_READ_ONLY;
                 mysql_stmt_attr_set(stmt, STMT_ATTR_CURSOR_TYPE, &cursor);
@@ -299,7 +298,7 @@ PreparedStatement_T MysqlConnection_prepareStatement(T C, const char *sql, va_li
         va_copy(ap_copy, ap);
         StringBuffer_vset(C->sb, sql, ap_copy);
         va_end(ap_copy);
-        if (prepare(C, StringBuffer_toString(C->sb), StringBuffer_length(C->sb), &stmt)) {
+        if (_prepare(C, StringBuffer_toString(C->sb), StringBuffer_length(C->sb), &stmt)) {
                 int parameterCount = (int)mysql_stmt_param_count(stmt);
 		return PreparedStatement_new(MysqlPreparedStatement_new(stmt, C->maxRows, parameterCount), (Pop_T)&mysqlpops, parameterCount);
         }
@@ -315,14 +314,6 @@ const char *MysqlConnection_getLastError(T C) {
 }
 
 
-/* Class method: MySQL client library finalization */
-void MysqlConnection_onstop(void) {
-        if (mysql_get_client_version() >= 50003)
-                mysql_library_end();
-        else
-                mysql_server_end();
-}
-
 #ifdef PACKAGE_PROTECTED
 #pragma GCC visibility pop
 #endif
