@@ -38,8 +38,6 @@ int MysqlConnection_execute(T C, const char *sql, va_list ap);
 ResultSet_T MysqlConnection_executeQuery(T C, const char *sql, va_list ap);
 PreparedStatement_T MysqlConnection_prepareStatement(T C, const char *sql, va_list ap);
 const char *MysqlConnection_getLastError(T C);
-/* Event handlers */
-void MysqlConnection_onstop(void);
 #undef T
 #endif
 
