@@ -48,17 +48,16 @@
 #define MYSQL_OK 0
 
 const struct Rop_T mysqlrops = {
-	"mysql",
-        MysqlResultSet_free,
-        MysqlResultSet_getColumnCount,
-        MysqlResultSet_getColumnName,
-        MysqlResultSet_getColumnSize,
-        MysqlResultSet_next,
-        MysqlResultSet_isnull,
-        MysqlResultSet_getString,
-        MysqlResultSet_getBlob,
-        NULL, // getTimestamp is handled in ResultSet
-        NULL  // getDateTime is handled in ResultSet
+	.name           = "mysql",
+        .free           = MysqlResultSet_free,
+        .getColumnCount = MysqlResultSet_getColumnCount,
+        .getColumnName  = MysqlResultSet_getColumnName,
+        .getColumnSize  = MysqlResultSet_getColumnSize,
+        .next           = MysqlResultSet_next,
+        .isnull         = MysqlResultSet_isnull,
+        .getString      = MysqlResultSet_getString,
+        .getBlob        = MysqlResultSet_getBlob
+        // getTimestamp and getDateTime is handled in ResultSet
 };
 
 typedef struct column_t {
@@ -87,7 +86,7 @@ struct T {
 /* ------------------------------------------------------- Private methods */
 
 
-static inline void ensureCapacity(T R, int i) {
+static inline void _ensureCapacity(T R, int i) {
         if ((R->columns[i].real_length > R->bind[i].buffer_length)) {
                 /* Column was truncated, resize and fetch column directly. */
                 RESIZE(R->columns[i].buffer, R->columns[i].real_length + 1);
@@ -217,7 +216,7 @@ const char *MysqlResultSet_getString(T R, int columnIndex) {
         int i = checkAndSetColumnIndex(columnIndex, R->columnCount);
         if (R->columns[i].is_null)
                 return NULL;
-        ensureCapacity(R, i);
+        _ensureCapacity(R, i);
         R->columns[i].buffer[R->columns[i].real_length] = 0;
         return R->columns[i].buffer;
 }
@@ -228,7 +227,7 @@ const void *MysqlResultSet_getBlob(T R, int columnIndex, int *size) {
         int i = checkAndSetColumnIndex(columnIndex, R->columnCount);
         if (R->columns[i].is_null)
                 return NULL;
-        ensureCapacity(R, i);
+        _ensureCapacity(R, i);
         *size = (int)R->columns[i].real_length;
         return R->columns[i].buffer;
 }
