@@ -53,22 +53,21 @@
 /* ----------------------------------------------------------- Definitions */
 
 const struct Cop_T oraclesqlcops = {
-        "oracle",
-        OracleConnection_onstop,
-        OracleConnection_new,
-        OracleConnection_free,
-        OracleConnection_setQueryTimeout,
-        OracleConnection_setMaxRows,
-        OracleConnection_ping,
-        OracleConnection_beginTransaction,
-        OracleConnection_commit,
-        OracleConnection_rollback,
-        OracleConnection_lastRowId,
-        OracleConnection_rowsChanged,
-        OracleConnection_execute,
-        OracleConnection_executeQuery,
-        OracleConnection_prepareStatement,
-        OracleConnection_getLastError
+        .name 		 	= "oracle",
+        .new 		 	= OracleConnection_new,
+        .free 		 	= OracleConnection_free,
+        .setQueryTimeout 	= OracleConnection_setQueryTimeout,
+        .setMaxRows 	 	= OracleConnection_setMaxRows,
+        .ping		 	= OracleConnection_ping,
+        .beginTransaction       = OracleConnection_beginTransaction,
+        .commit			= OracleConnection_commit,
+        .rollback		= OracleConnection_rollback,
+        .lastRowId		= OracleConnection_lastRowId,
+        .rowsChanged		= OracleConnection_rowsChanged,
+        .execute		= OracleConnection_execute,
+        .executeQuery		= OracleConnection_executeQuery,
+        .prepareStatement	= OracleConnection_prepareStatement,
+        .getLastError		= OracleConnection_getLastError
 };
 
 #define ERB_SIZE 152
@@ -98,7 +97,7 @@ extern const struct Pop_T oraclepops;
 /* ------------------------------------------------------- Private methods */
 
 
-static int doConnect(T C, URL_T url, char**  error) {
+static int _doConnect(T C, URL_T url, char**  error) {
 #define ERROR(e) do {*error = Str_dup(e); return false;} while (0)
 #define ORAERROR(e) do{ *error = Str_dup(OracleConnection_getLastError(e)); return false;} while(0)
         const char *database, *username, *password;
@@ -174,7 +173,7 @@ T OracleConnection_new(URL_T url, char **error) {
         C->url = url;
         C->sb = StringBuffer_create(STRLEN);
         C->timeout = SQL_DEFAULT_TIMEOUT;
-        if (! doConnect(C, url, error)) {
+        if (! _doConnect(C, url, error)) {
                 OracleConnection_free(&C);
                 return NULL;
         }
@@ -405,10 +404,6 @@ const char *OracleConnection_getLastError(T C) {
         return C->erb;
 }
 
-/* Oracle client library finalization */
-void OracleConnection_onstop(void) {
-        // Not needed, OracleConnection_free handle finalization
-}
 
 #ifdef PACKAGE_PROTECTED
 #pragma GCC visibility pop
