@@ -26,21 +26,14 @@
 #ifndef ORACLE_RESULTSET_INCLUDED
 #define ORACLE_RESULTSET_INCLUDED
 #define T ResultSetDelegate_T
-T OracleResultSet_new(OCIStmt* stmt, OCIEnv* env, OCIError* err, OCISvcCtx* svc, int need_free, int max_row);
+T OracleResultSet_new(OCIStmt* stmt, OCIEnv* env, OCISession* usr, OCIError* err, OCISvcCtx* svc, int need_free, int max_row);
 void OracleResultSet_free(T *R);
 int  OracleResultSet_getColumnCount(T R);
-const char *OracleResultSet_getColumnName(T R, int column);
-int  OracleResultSet_next(T R);
+const char *OracleResultSet_getColumnName(T R, int columnIndex);
 long OracleResultSet_getColumnSize(T R, int columnIndex);
+int  OracleResultSet_next(T R);
+int OracleResultSet_isnull(T R, int columnIndex);
 const char *OracleResultSet_getString(T R, int columnIndex);
-const char *OracleResultSet_getStringByName(T R, const char *columnName);
-int OracleResultSet_getInt(T R, int columnIndex);
-int OracleResultSet_getIntByName(T R, const char *columnName);
-long long int OracleResultSet_getLLong(T R, int columnIndex);
-long long int OracleResultSet_getLLongByName(T R, const char *columnName);
-double OracleResultSet_getDouble(T R, int columnIndex);
-double OracleResultSet_getDoubleByName(T R, const char *columnName);
 const void *OracleResultSet_getBlob(T R, int columnIndex, int *size);
-const void *OracleResultSet_getBlobByName(T R, const char *columnName, int *size);
 #undef T
 #endif
