@@ -38,8 +38,6 @@ int PostgresqlConnection_execute(T C, const char *sql, va_list ap);
 ResultSet_T PostgresqlConnection_executeQuery(T C, const char *sql, va_list ap);
 PreparedStatement_T PostgresqlConnection_prepareStatement(T C, const char *sql, va_list ap);
 const char *PostgresqlConnection_getLastError(T C);
-/* Event handlers */
-void  PostgresqlConnection_onstop(void);
 #undef T
 #endif
 
