@@ -50,22 +50,21 @@
 
 
 const struct Cop_T sqlite3cops = {
-        "sqlite",
-        SQLiteConnection_onstop,
-        SQLiteConnection_new,
-        SQLiteConnection_free,
-        SQLiteConnection_setQueryTimeout,
-        SQLiteConnection_setMaxRows,
-        SQLiteConnection_ping,
-        SQLiteConnection_beginTransaction,
-        SQLiteConnection_commit,
-        SQLiteConnection_rollback,
-        SQLiteConnection_lastRowId,
-        SQLiteConnection_rowsChanged,
-        SQLiteConnection_execute,
-        SQLiteConnection_executeQuery,
-        SQLiteConnection_prepareStatement,
-        SQLiteConnection_getLastError
+        .name 		 	= "sqlite",
+        .new 		 	= SQLiteConnection_new,
+        .free 		 	= SQLiteConnection_free,
+        .setQueryTimeout 	= SQLiteConnection_setQueryTimeout,
+        .setMaxRows 	 	= SQLiteConnection_setMaxRows,
+        .ping		 	= SQLiteConnection_ping,
+        .beginTransaction	= SQLiteConnection_beginTransaction,
+        .commit			= SQLiteConnection_commit,
+        .rollback		= SQLiteConnection_rollback,
+        .lastRowId		= SQLiteConnection_lastRowId,
+        .rowsChanged		= SQLiteConnection_rowsChanged,
+        .execute		= SQLiteConnection_execute,
+        .executeQuery		= SQLiteConnection_executeQuery,
+        .prepareStatement	= SQLiteConnection_prepareStatement,
+        .getLastError		= SQLiteConnection_getLastError
 };
 
 #define T ConnectionDelegate_T
@@ -85,7 +84,7 @@ extern const struct Pop_T sqlite3pops;
 /* ------------------------------------------------------- Private methods */
 
 
-static sqlite3 *doConnect(URL_T url, char **error) {
+static sqlite3 *_doConnect(URL_T url, char **error) {
         int status;
 	sqlite3 *db;
         const char *path = URL_getPath(url);
@@ -95,6 +94,17 @@ static sqlite3 *doConnect(URL_T url, char **error) {
         }
         /* Shared cache mode help reduce database lock problems if libzdb is used with many threads */
 #if SQLITE_VERSION_NUMBER >= 3005000
+#ifndef DARWIN
+        /*
+         SQLite doc e.al.: "sqlite3_enable_shared_cache is disabled on MacOS X 10.7 and iOS version 5.0 and
+         will always return SQLITE_MISUSE. On those systems, shared cache mode should be enabled
+         per-database connection via sqlite3_open_v2() with SQLITE_OPEN_SHAREDCACHE".
+         As of OS X 10.10.4 this method is still deprecated and it is unclear if the recomendation above
+         holds as SQLite from 3.5 requires that both sqlite3_enable_shared_cache() _and_
+         sqlite3_open_v2(SQLITE_OPEN_SHAREDCACHE) is used to enable shared cache (!).
+         */
+        sqlite3_enable_shared_cache(true);
+#endif
         status = sqlite3_open_v2(path, &db, SQLITE_OPEN_READWRITE | SQLITE_OPEN_CREATE | SQLITE_OPEN_SHAREDCACHE, NULL);
 #else
         status = sqlite3_open(path, &db);
@@ -108,7 +118,7 @@ static sqlite3 *doConnect(URL_T url, char **error) {
 }
 
 
-static inline void executeSQL(T C, const char *sql) {
+static inline void _executeSQL(T C, const char *sql) {
 #if defined SQLITEUNLOCK && SQLITE_VERSION_NUMBER >= 3006012
         C->lastError = sqlite3_blocking_exec(C->db, sql, NULL, NULL, NULL);
 #else
@@ -117,7 +127,7 @@ static inline void executeSQL(T C, const char *sql) {
 }
 
 
-static int setProperties(T C, char **error) {
+static int _setProperties(T C, char **error) {
         const char **properties = URL_getParameterNames(C->url);
         if (properties) {
                 StringBuffer_clear(C->sb);
@@ -133,7 +143,7 @@ static int setProperties(T C, char **error) {
                         else
                                 StringBuffer_append(C->sb, "PRAGMA %s = %s; ", properties[i], URL_getParameter(C->url, properties[i]));
                 }
-                executeSQL(C, StringBuffer_toString(C->sb));
+                _executeSQL(C, StringBuffer_toString(C->sb));
                 if (C->lastError != SQLITE_OK) {
                         *error = Str_cat("unable to set database pragmas -- %s", sqlite3_errmsg(C->db));
                         return false;
@@ -155,14 +165,14 @@ T SQLiteConnection_new(URL_T url, char **error) {
         sqlite3 *db;
 	assert(url);
         assert(error);
-        if (! (db = doConnect(url, error)))
+        if (! (db = _doConnect(url, error)))
                 return NULL;
 	NEW(C);
         C->db = db;
         C->url = url;
         C->timeout = SQL_DEFAULT_TIMEOUT;
         C->sb = StringBuffer_create(STRLEN);
-        if (! setProperties(C, error))
+        if (! _setProperties(C, error))
                 SQLiteConnection_free(&C);
 	return C;
 }
@@ -192,28 +202,28 @@ void SQLiteConnection_setMaxRows(T C, int max) {
 
 int SQLiteConnection_ping(T C) {
         assert(C);
-        executeSQL(C, "select 1;");
+        _executeSQL(C, "select 1;");
         return (C->lastError == SQLITE_OK);
 }
 
 
 int SQLiteConnection_beginTransaction(T C) {
 	assert(C);
-        executeSQL(C, "BEGIN TRANSACTION;");
+        _executeSQL(C, "BEGIN TRANSACTION;");
         return (C->lastError == SQLITE_OK);
 }
 
 
 int SQLiteConnection_commit(T C) {
 	assert(C);
-        executeSQL(C, "COMMIT TRANSACTION;");
+        _executeSQL(C, "COMMIT TRANSACTION;");
         return (C->lastError == SQLITE_OK);
 }
 
 
 int SQLiteConnection_rollback(T C) {
 	assert(C);
-        executeSQL(C, "ROLLBACK TRANSACTION;");
+        _executeSQL(C, "ROLLBACK TRANSACTION;");
         return (C->lastError == SQLITE_OK);
 }
 
@@ -236,7 +246,7 @@ int SQLiteConnection_execute(T C, const char *sql, va_list ap) {
         va_copy(ap_copy, ap);
         StringBuffer_vset(C->sb, sql, ap_copy);
         va_end(ap_copy);
-	executeSQL(C, StringBuffer_toString(C->sb));
+	_executeSQL(C, StringBuffer_toString(C->sb));
 	return (C->lastError == SQLITE_OK);
 }
 
@@ -291,13 +301,6 @@ const char *SQLiteConnection_getLastError(T C) {
 }
 
 
-/* Class Method: SQLite3 client library finalization */
-void SQLiteConnection_onstop(void) {
-#if SQLITE_VERSION_NUMBER >= 3006000
-        sqlite3_shutdown();
-#endif
-}
-
 #ifdef PACKAGE_PROTECTED
 #pragma GCC visibility pop
 #endif
