@@ -28,11 +28,12 @@ T SQLitePreparedStatement_new(sqlite3 *db, void *stmt, int maxRows);
 void SQLitePreparedStatement_free(T *P);
 void SQLitePreparedStatement_setString(T P, int parameterIndex, const char *x);
 void SQLitePreparedStatement_setInt(T P, int parameterIndex, int x);
-void SQLitePreparedStatement_setLLong(T P, int parameterIndex, long long int x);
+void SQLitePreparedStatement_setLLong(T P, int parameterIndex, long long x);
 void SQLitePreparedStatement_setDouble(T P, int parameterIndex, double x);
+void SQLitePreparedStatement_setTimestamp(T P, int parameterIndex, time_t x);
 void SQLitePreparedStatement_setBlob(T P, int parameterIndex, const void *x, int size);
 void SQLitePreparedStatement_execute(T P);
 ResultSet_T SQLitePreparedStatement_executeQuery(T P);
-long long int SQLitePreparedStatement_rowsChanged(T P);
+long long SQLitePreparedStatement_rowsChanged(T P);
 #undef T
 #endif
