@@ -46,17 +46,17 @@
 
 
 const struct Rop_T sqlite3rops = {
-	"sqlite",
-        SQLiteResultSet_free,
-        SQLiteResultSet_getColumnCount,
-        SQLiteResultSet_getColumnName,
-        SQLiteResultSet_getColumnSize,
-        SQLiteResultSet_next,
-        SQLiteResultSet_isnull,
-        SQLiteResultSet_getString,
-        SQLiteResultSet_getBlob,
-        SQLiteResultSet_getTimestamp,
-        SQLiteResultSet_getDateTime
+	.name           = "sqlite",
+        .free           = SQLiteResultSet_free,
+        .getColumnCount = SQLiteResultSet_getColumnCount,
+        .getColumnName  = SQLiteResultSet_getColumnName,
+        .getColumnSize  = SQLiteResultSet_getColumnSize,
+        .next           = SQLiteResultSet_next,
+        .isnull         = SQLiteResultSet_isnull,
+        .getString      = SQLiteResultSet_getString,
+        .getBlob        = SQLiteResultSet_getBlob,
+        .getTimestamp   = SQLiteResultSet_getTimestamp,
+        .getDateTime    = SQLiteResultSet_getDateTime
 };
 
 #define T ResultSetDelegate_T
@@ -166,9 +166,8 @@ const void *SQLiteResultSet_getBlob(T R, int columnIndex, int *size) {
 time_t SQLiteResultSet_getTimestamp(T R, int columnIndex) {
         assert(R);
         int i = checkAndSetColumnIndex(columnIndex, R->columnCount);
-        if (sqlite3_column_type(R->stmt, i) == SQLITE_INTEGER) {
+        if (sqlite3_column_type(R->stmt, i) == SQLITE_INTEGER)
                 return (time_t)sqlite3_column_int64(R->stmt, i);
-        }
         // Not integer storage class, try to parse as time string
         return Time_toTimestamp(sqlite3_column_text(R->stmt, i));
 }
