@@ -180,10 +180,10 @@ static void testTime() {
         
         printf("=> Test3: Time_toString\n");
         {
-                char *t = Time_toString(1387010338, (char[20]){0});
+                char *t = Time_toString(1387010338, (char[20]){});
                 assert(Str_isEqual(t, "2013-12-14 08:38:58"));
                 printf("\tResult: %s\n", t);
-                // Assert time is converted in UTC timezone
+                // Assert time is converted to UTC
                 Time_toString(0, t);
                 assert(Str_isEqual(t, "1970-01-01 00:00:00"));
                 printf("\tResult: %s\n", t);
@@ -283,20 +283,23 @@ static void testTime() {
         
         printf("=> Test5: Time_toTimestamp\n");
         {
-                // Time, fraction of second is ignored
+                // Time, fraction of second is ignored. No timezone in string means UTC
                 time_t t = Time_toTimestamp("2013-12-15 00:12:58.123456");
                 assert(t == 1387066378);
-                // TimeZone east, ignored. String is parsed as UTC
-                t = Time_toTimestamp("Tokyo timezone: 2013-12-15 00:12:58+09:00");
+                // TimeZone east
+                t = Time_toTimestamp("Tokyo timezone: 2013-12-15 09:12:58+09:00");
                 assert(t == 1387066378);
-                // TimeZone west, ignored. String is parsed as UTC
-                t = Time_toTimestamp("New York timezone: 2013-12-15 00:12:58-05:00");
+                // TimeZone west
+                t = Time_toTimestamp("New York timezone: 2013-12-14 19:12:58-05:00");
+                assert(t == 1387066378);
+                // TimeZone east with hour and minute offset
+                t = Time_toTimestamp("Nepal timezone: 2013-12-15 05:57:58+05:45");
                 assert(t == 1387066378);
                 // TimeZone Zulu
                 t = Time_toTimestamp("Grenwich timezone: 2013-12-15 00:12:58Z");
                 assert(t == 1387066378);
                 // Compressed
-                t = Time_toTimestamp("20131215001258-0500");
+                t = Time_toTimestamp("20131214191258-0500");
                 assert(t == 1387066378);
                 // Invalid timestamp string
                 TRY {
@@ -445,53 +448,7 @@ static void testURL() {
         }
         printf("=> Test7: OK\n\n");
         
-        printf("=> Test8: Normalized url\n");
-        {
-                char path[STRLEN];
-                snprintf(path, STRLEN, "/a/../b/../");
-                printf("\tResult: /a/../b/../ -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/", path));
-                snprintf(path, STRLEN, "/../../a");
-                printf("\tResult: /../../a -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/a", path));
-                snprintf(path, STRLEN, "/foo//");
-                printf("\tResult: /foo// -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/foo/", path));
-                snprintf(path, STRLEN, "//foo/");
-                printf("\tResult: //foo/ -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/foo/", path));
-                snprintf(path, STRLEN, "/foo/./");
-                printf("\tResult: /foo/./ -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/foo/", path));
-                snprintf(path, STRLEN, "/foo/../bar");
-                printf("\tResult: /foo/../bar -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/bar", path));
-                snprintf(path, STRLEN, "/foo/../bar/");
-                printf("\tResult: /foo/../bar/ -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/bar/", path));
-                snprintf(path, STRLEN, "/../bar/../baz");
-                printf("\tResult: /../bar/../baz -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/baz", path));
-                snprintf(path, STRLEN, "//foo//./bar");
-                printf("\tResult: //foo//./bar -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/foo/bar", path));
-                snprintf(path, STRLEN, "/foo/..");
-                printf("\tResult: /foo/.. -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/", path));
-                snprintf(path, STRLEN, "/a/../b/../../a");
-                printf("\tResult: /a/../b/../../a -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/a", path));
-                snprintf(path, STRLEN, "/.././../");
-                printf("\tResult: /.././../ -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/", path));
-                *path = 0;
-                printf("\tResult: \"\" -> %s\n", URL_normalize(path));
-                assert(Str_isEqual("/", path));
-                assert(NULL == URL_normalize(NULL));
-        }
-        printf("=> Test8: OK\n\n");
-        
-        printf("=> Test9: unescape\n");
+        printf("=> Test8: unescape\n");
         {
                 char s9a[] = "";
 		char s9x[] = "http://www.tildeslash.com/%";
@@ -506,9 +463,9 @@ static void testURL() {
                 assert(Str_isEqual(URL_unescape(s9x), "http://www.tildeslash.com/"));
                 assert(Str_isEqual(URL_unescape(s9y), "http://www.tildeslash.com/"));
         }
-        printf("=> Test9: OK\n\n");
+        printf("=> Test8: OK\n\n");
         
-        printf("=> Test10: escape\n");
+        printf("=> Test9: escape\n");
         {
                 char s10[] = "http://www.tildeslash.com/<>#%{}|\\^~[] `";
                 char *rs10 = URL_escape(s10);
@@ -518,9 +475,9 @@ static void testURL() {
                 assert(! URL_escape(NULL));
                 FREE(rs10);
         }
-        printf("=> Test10: OK\n\n");
+        printf("=> Test9: OK\n\n");
         
-        printf("=> Test11: URL parameters,\n\tmysql://localhost:3306/db?"
+        printf("=> Test10: URL parameters,\n\tmysql://localhost:3306/db?"
                "user=root&password=swordfish&charset=utf8\n");
         {
                 int i = 0;
@@ -536,9 +493,9 @@ static void testURL() {
                 assert(i == 3);
                 URL_free(&url);
         }
-        printf("=> Test11: OK\n\n");
+        printf("=> Test10: OK\n\n");
            
-        printf("=> Test12: auto unescape of credentials, path and param values\n");
+        printf("=> Test11: auto unescape of credentials, path and param values\n");
         {
                 url = URL_new("mysql://r%40ot:p%40ssword@localhost/test%20dir?user=r%26ot&password=pass%3Dword");
                 assert(IS(URL_getUser(url), "r@ot"));
@@ -548,6 +505,42 @@ static void testURL() {
                 assert(IS(URL_getParameter(url, "password"), "pass=word"));
                 URL_free(&url);
         }
+        printf("=> Test11: OK\n\n");
+
+        printf("=> Test12: IPv4 and IPv6 hosts\n");
+        {
+                // IPv4
+                url = URL_new("mysql://r%40ot:p%40ssword@192.168.2.42:3306/test?user=r%26ot&password=pass%3Dword");
+                assert(IS(URL_getUser(url), "r@ot"));
+                assert(IS(URL_getPassword(url), "p@ssword"));
+                assert(IS(URL_getHost(url), "192.168.2.42"));
+                assert(URL_getPort(url) == 3306);
+                assert(IS(URL_getPath(url), "/test"));
+                assert(IS(URL_getParameter(url, "user"), "r&ot"));
+                assert(IS(URL_getParameter(url, "password"), "pass=word"));
+                URL_free(&url);
+                // IPv6
+                url = URL_new("mysql://r%40ot:p%40ssword@[2001:db8:85a3::8a2e:370:7334]:3306/test?user=r%26ot&password=pass%3Dword");
+                assert(IS(URL_getUser(url), "r@ot"));
+                assert(IS(URL_getPassword(url), "p@ssword"));
+                // Assert that IP6 brackets are removed
+                assert(IS(URL_getHost(url), "2001:db8:85a3::8a2e:370:7334"));
+                assert(URL_getPort(url) == 3306);
+                assert(IS(URL_getPath(url), "/test"));
+                assert(IS(URL_getParameter(url, "user"), "r&ot"));
+                assert(IS(URL_getParameter(url, "password"), "pass=word"));
+                // Assert that IP6 brackets are put back in toString
+                assert(IS(URL_toString(url), "mysql://r@ot:p@ssword@[2001:db8:85a3::8a2e:370:7334]:3306/test?user=r%26ot&password=pass%3Dword"));
+                URL_free(&url);
+                // IPv6 localhost
+                url = URL_new("mysql://[fe80::1%lo0]/");
+                // Assert that IP6 brackets are removed
+                assert(IS(URL_getHost(url), "fe80::1%lo0"));
+                assert(URL_getPort(url) == 3306);
+                // Assert that IP6 brackets are put back in toString
+                assert(IS(URL_toString(url), "mysql://[fe80::1%lo0]/"));
+                URL_free(&url);
+        }
         printf("=> Test12: OK\n\n");
 
         printf("============> URL Tests: OK\n\n");
@@ -874,16 +867,10 @@ static void testStringBuffer() {
                 assert(Str_isEqual(StringBuffer_toString(sb), "select a from b"));
                 StringBuffer_free(&sb);
                 assert(sb == NULL);
-                // Remove last semicolon
-                sb = StringBuffer_new("select * from host;");
-                StringBuffer_trim(sb);
-                assert(Str_isEqual(StringBuffer_toString(sb), "select * from host"));
-                StringBuffer_free(&sb);
-                assert(sb == NULL);
-                // Remove trailing white space and last semicolons
+                // Remove white space
                 sb = StringBuffer_new("\t select a from b; \r\n");
                 StringBuffer_trim(sb);
-                assert(Str_isEqual(StringBuffer_toString(sb), "select a from b"));
+                assert(Str_isEqual(StringBuffer_toString(sb), "select a from b;"));
                 StringBuffer_free(&sb);
                 assert(sb == NULL);
         }
@@ -917,7 +904,6 @@ static void testStringBuffer() {
 
 int main(void) {
         Exception_init();
-        setenv("TZ", "Europe/Oslo" , 1);
 	testStr();
 	testMem();
 	testTime();
